﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace ThinkGeoSandBox
{
    public class UseADifferentProjectionForAFeatureLayer : UserControl
    {
        public UseADifferentProjectionForAFeatureLayer()
        {
            InitializeComponent();
        }

        private void UserADifferentProjectionForAFeatureLayer_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.Meter;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            // If want to know more srids, please refer Projections.rtf in Documentation folder.
            Proj4Projection proj4Projection = new Proj4Projection();
            proj4Projection.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
            proj4Projection.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"C:\Program Files (x86)\ThinkGeo\Map Suite Desktop Evaluation Edition 7.0\Samples\SampleData\Data\Countries02.shp");

            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.FeatureSource.Projection = proj4Projection;


            worldLayer.Open();
            proj4Projection.Open();
            winformsMap1.CurrentExtent = proj4Projection.ConvertToExternalProjection(new RectangleShape(-240, 68, 20, 40));//  worldLayer.GetBoundingBox();
            proj4Projection.Close();
            worldLayer.Close();

            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("WorldLayer", worldLayer);
            winformsMap1.Overlays.Add(staticOverlay);

            AddWeather(proj4Projection);

            winformsMap1.Refresh();
        }

        private void AddWeather(Projection projection)
        {
            ShapeFileFeatureLayer windLayer = new ShapeFileFeatureLayer(@"ShapeFile\Wind_20140426_0000_p0.shp");
            windLayer.Open();
            List<Feature> allFeatures = windLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns).ToList();
            windLayer.Close();

            
            List<Feature> contourLines = allFeatures.Where(a => a.ColumnValues["contour"] != "").ToList();
            List<MultilineShape> mlShape = contourLines.Select(a => (MultilineShape) a.GetShape()).ToList();
            List<LineShape> lineShapes = mlShape.SelectMany(a => a.Lines).ToList(); //.Where(b=> b.Vertices.Count == 5)

            List<FeatureSourceColumn> columns = new List<FeatureSourceColumn>();
            columns.Add(new FeatureSourceColumn("wind_"));
            InMemoryFeatureLayer layer = new InMemoryFeatureLayer(columns.ToArray(), lineShapes.ToArray());
            layer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Red, 1, false);
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Red, GeoColor.StandardColors.Red);
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layer.FeatureSource.Projection = projection;

            LayerOverlay overlay = new LayerOverlay();
            winformsMap1.Overlays.Add("test", overlay);
            overlay.Layers.Add(layer);
        }

        private WinformsMap winformsMap1;

        #region Component Designer generated code

        private System.ComponentModel.IContainer components = null;

        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }



        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.winformsMap1 = new ThinkGeo.MapSuite.DesktopEdition.WinformsMap();
            this.SuspendLayout();
            // 
            // winformsMap1
            // 
            this.winformsMap1.BackColor = System.Drawing.Color.White;
            this.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.winformsMap1.Location = new System.Drawing.Point(0, 0);
            this.winformsMap1.Name = "winformsMap1";
            this.winformsMap1.Size = new System.Drawing.Size(740, 528);
            this.winformsMap1.TabIndex = 0;
            this.winformsMap1.Text = "winformsMap1";
            // 
            // UseADifferentProjectionForAFeatureLayer
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.Controls.Add(this.winformsMap1);
            this.Name = "UseADifferentProjectionForAFeatureLayer";
            this.Size = new System.Drawing.Size(740, 528);
            this.Load += new System.EventHandler(this.UserADifferentProjectionForAFeatureLayer_Load);
            this.ResumeLayout(false);

        }

        #endregion
    }


}
